Attribute VB_Name = "MSAPFunctions"
Option Explicit

' Global variables used to show in dialog boxes.

  Global bIsLoggedIn As Boolean           ' Keeps Track Of Login Status
  Global strSAPClient As Variant          ' Keeps Track Of SAP Login Client ID
  Global strSAPUser As Variant            ' Keeps Track Of SAP Login Username
  Global strSAPPassWord As Variant        ' Keeps Track Of SAP Login Password
  Global strSAPLanguage As Variant        ' Keeps Track Of SAP Login Language
  Global strSAPSystem As Variant          ' Keeps Track Of SAP Login System ID
  Public strIniPath As String             ' Keeps Track Of SAP Login File Path
  Public objSAPConnection As Object       ' SAP Connection Object
  Public objSAPFunctions As SAPFunctions  ' SAP Functions Object (Set Through Tools / References)
 
Public Sub SAPGetParams()
    
' Read SAP_Login.Ini File To Get SAP Login Variable Values
    
  strSAPClient = Trim$(IniRead(strIniPath, "SAP Connection", "Client", ""))
  strSAPUser = Trim$(IniRead(strIniPath, "SAP Connection", "User", ""))
  strSAPPassWord = Trim$(IniRead(strIniPath, "SAP Connection", "Password", ""))
  strSAPLanguage = Trim$(IniRead(strIniPath, "SAP Connection", "Language", ""))
  strSAPSystem = Trim$(IniRead(strIniPath, "SAP Connection", "System", ""))

End Sub

Public Sub SAPConnect()

' Login to SAP

  objSAPConnection.client = strSAPClient
  objSAPConnection.user = strSAPUser
  objSAPConnection.Password = strSAPPassWord
  objSAPConnection.language = strSAPLanguage
  objSAPConnection.System = strSAPSystem

' Check To See If Connection Was Successful
   
  If Not objSAPConnection.Logon(0, False) Then
    
    bIsLoggedIn = False
    
    PopText "Attention", "SAP Logon Failed, Please Contact Supervisor", True
    
    Clippership.Error_Log ("SAP Logon Failed - Check " & strIniPath & " Settings")
    
  Else
    
    bIsLoggedIn = True
  
  End If

End Sub

Public Sub SAPDisconnect()

' Log off SAP
    
  If bIsLoggedIn = True Then
    
    objSAPFunctions.Connection.logoff
  
    bIsLoggedIn = False
  
  End If
  
End Sub
  
Function SAPReadData()

' Check For SAP Login

  If bIsLoggedIn = True Then
  
' Send Information To SAP

    Dim Function_Call_Return As Boolean
    Dim RFC_Function
    Dim iTrys As Integer
    Dim sAnswer As String
   
    
' Set The SAP Object To The Custom SAP Function
  
    Set RFC_Function = objSAPFunctions.Add("ZCWD_CLIPPER_GETDATA")
    
    
' Set Inbound Parameter Of The Function
    
    RFC_Function.Exports("PKGID") = Trim(Clippership.GetVar("xPkgId")) ' Unit Number
   
       
' Make RFC Call To SAP (2 Trys If Necessary)
  
    iTrys = 0
  
    Do While iTrys < 2
    
      Function_Call_Return = RFC_Function.Call
    
      Delay (0.5)
      
      
' Check To See If Call Was Un-Successful, Display Error
    
      If Function_Call_Return = False Then
  
        PopText "Attention", "SAP RFC General Failure, Please Contact Supervisor", True
      
        Clippership.Error_Log ("SAP Request For " & Trim(Clippership.GetVar("xPkgId")) & " Failed, SAP RFC General Failure")
      
        iTrys = 2
              
              
' If No Results, Try Again
      
      ElseIf Len(Trim(RFC_Function.Imports("MESSAGE"))) <= 0 Then
      
         iTrys = iTrys + 1
                   
                   
' If Results Returned, Exit Loop
      
      ElseIf Len(Trim(RFC_Function.Imports("MESSAGE"))) > 0 Then
      
        iTrys = 2
      
      End If

    Loop
     
     
' If Nothing Returned, Log Error Message, Prompt For Manual
   
    If Upper(Trim(RFC_Function.Imports("MESSAGE"))) <> "GOOD" Then
      
              
      Clippership.Error_Log (Trim(RFC_Function.Imports("MESSAGE")) & " / Unit ID: " & Trim(Clippership.GetVar("xPkgId")))
                    
      DlgCreate "SAP Message", 10, 40
      DlgText 2, 2, Trim(RFC_Function.Imports("MESSAGE"))
      DlgText 4, 10, "Process As A Manual?"
      DlgButton 8, 10, "&Yes"
      DlgDefButton 8, 23, "&No"
      sAnswer = DlgDraw(True)
           
      If sAnswer = "Yes" Then
      
        Clippership.SetVar "xPkgId", "M" & Format(Date, "MMDDYYYY") & Format(Time, "HHMMSS")
        
        Clippership.Error_Log ("User Accepted Manual Data Entry For Unit: " & Trim(Clippership.GetVar("xPkgId")))
       
        bManual = True
                       
        PopText "Attention", "Press F9 To Enter Address", True
            
      Else
      
        Clippership.Error_Log ("User Declined Manual Data Entry For Unit: " & Trim(Clippership.GetVar("xPkgId")))
                  
        Clippership.ClearTrans
        
        Clippership.GotoField (1)
                
      End If
                     
                
' If Information Returned, Send To Clippership
  
    Else
      XC1 = Trim(RFC_Function.Imports("PAY_ACCT"))
      
' Check For Vailid Bill To Account Number
      
      If Len(Trim(RFC_Function.Imports("PAY_ACCT"))) > 0 And Len(Trim(RFC_Function.Imports("PAY_ACCT"))) <> 6 Then
      
        Clippership.Error_Log ("Invalid Bill To Recipient Account Number (" & Trim(RFC_Function.Imports("PAY_ACCT")) & ") For Unit: " & Trim(Clippership.GetVar("xPkgId")))
                  
        PopText "Attention", "Invalid Bill To Recipient Account Number For Shipment (" & Trim(RFC_Function.Imports("PAY_ACCT")) & ")", True
                  
        Clippership.ClearTrans
        
        Clippership.GotoField (1)

        Set RFC_Function = Nothing
      
        Exit Function
        
      End If
            
            
' Send Information To Clippership
            
      Clippership.SetVar "xShipTo1", Trim(RFC_Function.Imports("SHIPTO1"))   ' Company Name
      Clippership.SetVar "xShipTo2", Trim(RFC_Function.Imports("SHIPTO2"))   ' Company Name Line 2
      'Clippership.SetVar "xShipTo3", Trim(RFC_Function.Imports("SHIPTO3"))  ' Company Contact
      Clippership.SetVar "xShipTo4", Trim(RFC_Function.Imports("SHIPTO3"))   ' Company Address 1
      'Clippership.SetVar "xShipTo5", Trim(RFC_Function.Imports("SHIPTO5"))  ' Company Address 2
      'Clippership.SetVar "xShipTo6", Trim(RFC_Function.Imports("SHIPTO6"))  ' Company Address 3
      Clippership.SetVar "xShipTo7", Trim(RFC_Function.Imports("SHIPTO4")) & " " & Trim(RFC_Function.Imports("SHIPTO5"))  ' Company City / State
      Clippership.SetVar "xCust", Trim(RFC_Function.Imports("SHIPTO7"))      ' SAP Customer Number
      Clippership.SetVar "xZip", Trim(RFC_Function.Imports("ZIP"))           ' Company Zip
      Clippership.SetVar "xPhone", Trim(RFC_Function.Imports("PHONE"))       ' Company Phone
      Clippership.SetVar "xCountry", Trim(RFC_Function.Imports("COUNTRY"))   ' Company Country
      Clippership.SetVar "xCarrier", Trim(RFC_Function.Imports("CARRIER"))   ' Carrier Code
      Clippership.SetVar "xRef", Trim(RFC_Function.Imports("REF"))           ' SAP Reference Number
      Clippership.SetVar "xPay_Acct", Trim(RFC_Function.Imports("PAY_ACCT")) ' Bill Receipient Account Number
      Clippership.SetVar "xProd", Trim(RFC_Function.Imports("REF"))          ' Delivery Number
      Clippership.SetVar "xDesc", Trim(RFC_Function.Imports("CUST_PO1"))     ' PO Number 1
      Clippership.SetVar "xRemark", Trim(RFC_Function.Imports("CUST_PO2"))   ' PO Number 2
      Clippership.SetVar "xDept", Trim(RFC_Function.Imports("CUST_PO3"))          ' PO Number 3
                 
                
                
' Store Package Count / Order Count For Printing On Carrier Label
            
      iExpCount = AtoN(Trim(RFC_Function.Imports("TOT_NUM_PKG")))
      
      iOrdCount = AtoN(Trim(RFC_Function.Imports("NUM_PKG")))
        
' Display Address
                
      Clippership.Display
          
          
' Check Country
          
      If Upper(Trim(RFC_Function.Imports("COUNTRY"))) <> "US" Or Upper(Trim(RFC_Function.Imports("COUNTRY"))) <> "UNITED STATES" Or Trim(RFC_Function.Imports("COUNTRY")) <> "" Then
          
        Clippership.GotoRecord
       
      Else
      
        Clippership.RightTop "International"
        
        Clippership.GotoField (2)
      
      End If
       
    End If


' Reset Function Object

    Set RFC_Function = Nothing


' If No SAP Connection, Display Error

  Else

    PopText "SAP Connection Error", "No Connection with SAP Present, Please Contact Supervisor", True
 
    Clippership.Error_Log ("SAP Request For " & Trim(Clippership.GetVar("xPkgId")) & " Failed, No Connection with SAP Present")
  
  End If

End Function

Function SAPWriteData()

' Check For SAP Login

  If bIsLoggedIn = True Then
  
' Send Information To SAP

    Dim Function_Call_Return As Boolean
    Dim RFC_Function
    Dim iTrys As Integer
    
    
' Set The SAP Object To The Custom SAP Function
  
    Set RFC_Function = objSAPFunctions.Add("ZCWD_CLIPPER_UPDATE")
    
    
' Set Parameters Of The Function
  
' SAP Reference Number
  
    RFC_Function.Exports("REF") = Trim(Clippership.GetVar("xxRef"))
  
' Package Charges
  
    If AtoN(Clippership.GetVar("xxAccount")) = 2 Then
  
       ' Use Alternate Charge
  
       Dim dCharge As Double
       
       dCharge = AtoN(Clippership.GetVar("xxAlt_Chg1")) + AtoN(Clippership.GetVar("xxRef1_Chg")) + AtoN(Clippership.GetVar("xxRef2_Chg"))
  
       RFC_Function.Exports("TOT_CHG") = Trim(AtoC(dCharge))
     
    Else
    
       RFC_Function.Exports("TOT_CHG") = Trim(AtoC(Clippership.GetVar("xxTot_Chg")))
       
    End If
     
' Tracking Number
  
    RFC_Function.Exports("TRACK_NO") = Trim(Clippership.GetVar("xxTrack_No"))
     
' Shipping Weight
  
    RFC_Function.Exports("SHP_WGT") = Trim(AtoC(Clippership.GetVar("xxShp_Wgt")))
     
' Unit Handling Number
  
    RFC_Function.Exports("PKGID") = Trim(Clippership.GetVar("xxPkgId"))
     
   
' Make RFC Call To SAP (3 Trys If Necessary)
  
    iTrys = 0
  
    Do While iTrys < 3
    
      Function_Call_Return = RFC_Function.Call
    
      Delay (0.5)
            
            
' Check To See If Call Was Un-Successful, Display Error
    
      If Function_Call_Return = False Then
  
        PopText "Attention", "SAP RFC General Failure, Please Contact Supervisor", True
      
        Clippership.Error_Log ("SAP Update For " & Trim(Clippership.GetVar("xxPkgId")) & " Failed, SAP RFC General Failure")
      
        iTrys = 3
              
              
' If No Results, Try Again
      
      ElseIf Len(Trim(RFC_Function.Imports("STATUS"))) <= 0 Then
      
         iTrys = iTrys + 1
                   
                   
' If Results Returned, Exit Loop
      
      ElseIf Len(Trim(RFC_Function.Imports("STATUS"))) > 0 Then
      
        iTrys = 3
      
      End If

    Loop
     
     
' If Nothing Returned, Or Incorrect Status, Log Error Message, Notify Operator
   
    If Upper(Trim(RFC_Function.Imports("STATUS"))) <> "S" Then
      
      PopText "Attention", "Unable To Update Unit ID" & vbCrLf & vbCrLf & Trim(Clippership.GetVar("xxPkgId")) & vbCrLf & vbCrLf & Trim(RFC_Function.Imports("MESSAGE")), True
      
      Clippership.Error_Log ("Unable To Update Unit ID: " & Trim(Clippership.GetVar("xxPkgId")) & ", Message Returned = " & Trim(RFC_Function.Imports("MESSAGE")))
                
                
    End If
  

' Reset Function Object

    Set RFC_Function = Nothing

' No SAP Connection

  Else

    PopText "SAP Connection Error", "No Connection with SAP Present, Please Contact Supervisor", True
    
    Clippership.Error_Log ("SAP Update For " & Trim(Clippership.GetVar("xxPkgId")) & " Failed, No Connection with SAP Present")
  
  End If


End Function




